# cob-eda

## "올림픽" 발언 횟수 출

```bash력
$ from cob_eda import group_by_count
$ group_by_count()
```


## Dev
``bash
$ source .venv/bin/activate
$ pdm add pandas
$ pdm add -dG eda jupyterlab
```

## EDA
- run jupyterlab


## Ref
- [install jupyterlab](https://jupyter.org/install)
- [president-speech](https://pypi.org/project/president-speech/)

